@@ -1,4 +1,4 @@
-from .field import Field
+from .field import Field, UnsignedField1
 from .packet import Packet
 from .packet55v1 import Packet55v1
 from .parser import Parser
